@@ -246,3 +246,18 @@ class InterfaceNotFound(acos_errors.ACOSException):
         msg = ('vThunder instance {0} has no interface in network {1}.').format(comput_id,
                                                                                 network_id)
         super(InterfaceNotFound, self).__init__(msg=msg)
+
+
+class FlavorNotFound(cfg.ConfigFileValueError):
+    def __init__(self, flavor):
+        msg = ('Flavor {0} specified in the configuration file cannot be located,'
+               ' Please create the flavor in advance.').format(flavor)
+        super(FlavorNotFound, self).__init__(msg=msg)
+
+
+class IPAddressNotInSubnetRangeError(base.NetworkException):
+    def __init__(self, ip, subnet):
+        msg = ('Invalid IP address specified. ' +
+               'IP {0} out of range ' +
+               'for subnet {1}.').format(ip, subnet)
+        super(IPAddressNotInSubnetRangeError, self).__init__(msg)
