@@ -432,9 +432,26 @@ class UpdateVRIDForLoadbalancerResource(BaseDatabaseTask):
                           str(vrid.vrid_floating_ip), str(e))
 
 
+class GetLoadbalancersInProjectBySubnet(BaseDatabaseTask):
+
+    def execute(self, subnet, partition_project_list):
+        if partition_project_list:
+            try:
+                return self.loadbalancer_repo.get_lbs_by_subnet(
+                    db_apis.get_session(),
+                    project_ids=partition_project_list, subnet_id=subnet.id)
+            except Exception as e:
+                LOG.exception("Failed to get LBs for subnet %s due to %s ",
+                              subnet.id, str(e))
+                raise e
+        return 0
+
+
 class CountLoadbalancersInProjectBySubnet(BaseDatabaseTask):
 
     def execute(self, subnet, partition_project_list, use_device_flavor):
+        if not subnet:
+            return 0
         if not use_device_flavor and partition_project_list:
             try:
                 return self.loadbalancer_repo.get_lb_count_by_subnet(
@@ -450,6 +467,8 @@ class CountLoadbalancersInProjectBySubnet(BaseDatabaseTask):
 class CountMembersInProjectBySubnet(BaseDatabaseTask):
 
     def execute(self, subnet, partition_project_list):
+        if not subnet:
+            return 0
         if partition_project_list:
             try:
                 return self.member_repo.get_member_count_by_subnet(
@@ -689,8 +708,12 @@ class GetFlavorData(BaseDatabaseTask):
 
     def execute(self, lb_resource):
         flavor_id = a10_task_utils.attribute_search(lb_resource, 'flavor_id')
+        if not flavor_id:
+            flavor_id = CONF.a10_global.default_flavor_id
         if flavor_id:
             flavor = self.flavor_repo.get(db_apis.get_session(), id=flavor_id)
+            if not flavor and lb_resource.provisioning_status != "PENDING_DELETE":
+                raise exceptions.FlavorNotFound(flavor_id)
             if flavor and flavor.flavor_profile_id:
                 flavor_profile = self.flavor_profile_repo.get(
                     db_apis.get_session(),
@@ -699,6 +722,25 @@ class GetFlavorData(BaseDatabaseTask):
                 return self._format_keys(flavor_data)
 
 
+class CheckForL2DSRFlavor(BaseDatabaseTask):
+
+    def execute(self, lb_resource):
+        for lb in lb_resource:
+            flavor_id = a10_task_utils.attribute_search(lb, 'flavor_id')
+            if flavor_id:
+                flavor = self.flavor_repo.get(db_apis.get_session(), id=flavor_id)
+                if flavor and flavor.flavor_profile_id:
+                    flavor_profile = self.flavor_profile_repo.get(
+                        db_apis.get_session(),
+                        id=flavor.flavor_profile_id)
+                    flavor_data = json.loads(flavor_profile.flavor_data)
+                    deployment = flavor_data.get('deployment')
+                    if deployment and 'dsr_type' in deployment and \
+                            deployment['dsr_type'] == "l2dsr_transparent":
+                        return True
+        return False
+
+
 class GetNatPoolEntry(BaseDatabaseTask):
 
     def execute(self, member, nat_flavor=None):
@@ -979,6 +1021,7 @@ class ValidateComputeForProject(BaseDatabaseTask):
     """Validate compute_id got for the project"""
 
     def execute(self, loadbalancer, role):
+        vthunder = None
         vthunder_ids = self.vthunder_repo.get_vthunders_by_project_id_and_role(
             db_apis.get_session(), loadbalancer.project_id, role)
         for vthunder_id in vthunder_ids:
@@ -989,10 +1032,22 @@ class ValidateComputeForProject(BaseDatabaseTask):
                 db_apis.get_session(), vthunder.loadbalancer_id)
             if lb:
                 amphora = self.amphora_repo.get(db_apis.get_session(), load_balancer_id=lb.id)
+                if not amphora:
+                    """
+                        We don't support create loadbalancer in Thunder device and vthunder in
+                    same project now. So, this should caused by some error configuration.
+                    """
+
+                    LOG.error("Already use hardware thunder to create loadbalancer for"
+                              " this project. Can't create vthunder for the project.")
+                    raise exceptions.ProjectDeviceNotFound()
                 if amphora.compute_id == vthunder.compute_id:
                     LOG.debug("Successfully validated comput_id %s for the project %s",
                               vthunder.compute_id, vthunder.project_id)
                     break
+
+        if vthunder is None:
+            return None
         return vthunder.compute_id
 
 
